package Weed::Values;
use Weed::Perl;

our $VERSION = '0.0079';

use Weed::Values::Color;
use Weed::Values::ColorRGBA;
use Weed::Values::Image;
use Weed::Values::Rotation;
use Weed::Values::Vec2;
use Weed::Values::Vec3;
use Weed::Values::Vec4;

1;
__END__

=head1 NAME

Weed::Values - Bundle

=head1 SEE ALSO

L<Weed::Values::Color> 

L<Weed::Values::ColorRGBA> 

L<Weed::Values::Image> 

L<Weed::Values::Rotation> 

L<Weed::Values::Vec2> 

L<Weed::Values::Vec3> 

L<Weed::Values::Vec4> 

=cut
